@@ -12,11 +12,12 @@ class PicturePlugin(CMSPluginBase):
     
     def render(self, context, instance, placeholder):
         if instance.url:
-            link = instance.url
+            link = settings.dbgettext(instance.url)
         elif instance.page_link:
             link = instance.page_link.get_absolute_url()
         else:
             link = ""
+        instance.alt = settings.dbgettext(instance.alt)
         context.update({
             'picture':instance,
             'link':link, 
@@ -28,4 +29,4 @@ class PicturePlugin(CMSPluginBase):
         # TODO - possibly use 'instance' and provide a thumbnail image
         return settings.CMS_MEDIA_URL + u"images/plugins/image.png"
  
-plugin_pool.register_plugin(PicturePlugin)
\ No newline at end of file
+plugin_pool.register_plugin(PicturePlugin)
