@@ -1,23 +1,20 @@
-from django.conf.urls.defaults import *
-from django.contrib import admin
 from django.conf import settings
+from django.conf.urls.defaults import patterns, include, \
+    url
+from django.contrib import admin
 
 admin.autodiscover()
 
-admin.site.root_path = "/admin/" # there is probably a bug in django...
-
 urlpatterns = patterns('',
-    #(r'^admin/(.*)', admin.site.root),
     (r'^admin/', include(admin.site.urls)),
     (r'^jsi18n/(?P<packages>\S+?)/$', 'django.views.i18n.javascript_catalog'),
-    (r'^categories/', include('categories.urls')),
-    
     # just for testing - native way to sampleapp urls 
     # (r'^sampleapp-native/', include('sampleapp.urls')),
 )
 
 if settings.DEBUG:
     urlpatterns+= patterns('',
+        url(r'^media/cms/(?P<path>.*)$', 'django.views.static.serve', {'document_root': settings.CMS_MEDIA_ROOT, 'show_indexes': True}),
         url(r'^media/(?P<path>.*)$', 'django.views.static.serve', {'document_root': settings.MEDIA_ROOT, 'show_indexes': True})
     )
 
